@@ -114,6 +114,7 @@ public class PlaybackService extends MediaBrowserServiceCompat{
     private static final int SHOW_PROGRESS = 0;
     private static final int SHOW_TOAST = 1;
     private static final int END_MEDIASESSION = 2;
+    private static final int PUBLISH_STATE = 3;
 
     private static final long DELAY_DOUBLE_CLICK = 800L;
     private static final long DELAY_LONG_CLICK = 1000L;
@@ -250,6 +251,7 @@ public class PlaybackService extends MediaBrowserServiceCompat{
 
     @Override
     public int onStartCommand(Intent intent, int flags, int startId) {
+        if (AndroidUtil.isOOrLater && !VLCApplication.isForeground()) forceForeground();
         if (intent == null) return START_NOT_STICKY;
         final String action = intent.getAction();
         if (Intent.ACTION_MEDIA_BUTTON.equals(action)) {
@@ -263,8 +265,7 @@ public class PlaybackService extends MediaBrowserServiceCompat{
             if (playlistManager.hasCurrentMedia()) play();
             else loadLastAudioPlaylist();
         } else if (Constants.ACTION_PLAY_FROM_SEARCH.equals(action)) {
-            if (mMediaSession == null)
-                initMediaSession();
+            if (mMediaSession == null) initMediaSession();
             final Bundle extras = intent.getBundleExtra(Constants.EXTRA_SEARCH_BUNDLE);
             mMediaSession.getController().getTransportControls()
                     .playFromSearch(extras.getString(SearchManager.QUERY), extras);
@@ -551,7 +552,7 @@ public class PlaybackService extends MediaBrowserServiceCompat{
                     break;
                 case MediaPlayer.Event.PositionChanged:
                     updateWidgetPosition(event.getPositionChanged());
-                    publishState();
+                    mHandler.sendEmptyMessage(PUBLISH_STATE);
                     break;
                 case MediaPlayer.Event.Vout:
                     break;
@@ -616,6 +617,8 @@ public class PlaybackService extends MediaBrowserServiceCompat{
     private final Handler mHandler = new PlaybackServiceHandler(this);
 
     private static class PlaybackServiceHandler extends WeakHandler<PlaybackService> {
+        private long lastPublicationDate = 0L;
+
         PlaybackServiceHandler(PlaybackService fragment) {
             super(fragment);
         }
@@ -643,6 +646,13 @@ public class PlaybackService extends MediaBrowserServiceCompat{
                 case END_MEDIASESSION:
                     if (service.mMediaSession != null) service.mMediaSession.setActive(false);
                     break;
+                case PUBLISH_STATE:
+                    final long time = System.currentTimeMillis();
+                    if (time - lastPublicationDate > 1000L) {
+                        service.publishState();
+                        lastPublicationDate = time;
+                    }
+                    break;
             }
         }
     }
@@ -1082,15 +1092,18 @@ public class PlaybackService extends MediaBrowserServiceCompat{
         pscb.addCustomAction("repeat", getString(R.string.repeat_title), repeatResId);
 
         boolean mediaIsActive = state != PlaybackStateCompat.STATE_STOPPED;
+        boolean update = mMediaSession.isActive() != mediaIsActive;
 
         mMediaSession.setPlaybackState(pscb.build());
         mMediaSession.setActive(mediaIsActive);
         mMediaSession.setQueueTitle(getString(R.string.music_now_playing));
 
-        if (mediaIsActive)
-            sendStartSessionIdIntent();
-        else
-            sendStopSessionIdIntent();
+        if (update) {
+            if (mediaIsActive)
+                sendStartSessionIdIntent();
+            else
+                sendStopSessionIdIntent();
+        }
     }
 
     private void notifyTrackChanged() {
@@ -1194,13 +1207,40 @@ public class PlaybackService extends MediaBrowserServiceCompat{
 
     private void loadLastAudioPlaylist() {
         if (AndroidDevices.isAndroidTv) return;
-        if (mMedialibrary.isInitiated() && mLibraryReceiver == null) playlistManager.loadLastPlaylist(Constants.PLAYLIST_TYPE_AUDIO);
-        else registerMedialibrary(new Runnable() {
-                @Override
-                public void run() {
-                    playlistManager.loadLastPlaylist(Constants.PLAYLIST_TYPE_AUDIO);
-                }
-            });
+        if (mMedialibrary.isInitiated() && mLibraryReceiver == null) {
+            if (!playlistManager.loadLastPlaylist(Constants.PLAYLIST_TYPE_AUDIO)) stopSelf();
+        } else registerMedialibrary(new Runnable() {
+            @Override
+            public void run() {
+                if (!playlistManager.loadLastPlaylist(Constants.PLAYLIST_TYPE_AUDIO)) stopSelf();
+            }
+        });
+    }
+
+    private void forceForeground() {
+        final Context ctx = PlaybackService.this;
+        final MediaSessionCompat.Token sessionToken = mMediaSession.getSessionToken();
+        final Notification notification = NotificationHelper.createPlaybackNotification(ctx,
+                false, ctx.getResources().getString(R.string.loading), "", "",
+                null, false, sessionToken, getSessionPendingIntent());
+        PlaybackService.this.startForeground(3, notification);
+        mIsForeground = true;
+        ExecutorHolder.executorService.execute(new Runnable() {
+            @Override
+            public void run() {
+                final Bitmap cover = BitmapFactory.decodeResource(ctx.getResources(), R.drawable.ic_no_media);
+                VLCApplication.runOnMainThread(new Runnable() {
+                    @Override
+                    public void run() {
+                        final Notification notification = NotificationHelper.createPlaybackNotification(ctx,
+                                false, ctx.getResources().getString(R.string.loading), "", "",
+                                cover, false, sessionToken, getSessionPendingIntent());
+                        PlaybackService.this.startForeground(3, notification);
+                        mIsForeground = true;
+                    }
+                });
+            }
+        });
     }
 
     public void loadLastPlaylist(int type) {
