@@ -120,11 +120,10 @@ public class FileUtils {
             final int column_index = cursor.getColumnIndexOrThrow(MediaStore.Images.Media.DATA);
             cursor.moveToFirst();
             return cursor.getString(column_index);
-        } catch (IllegalArgumentException e) {
+        } catch (IllegalArgumentException|SecurityException e) {
                 return "";
         } finally {
-            if (cursor != null && !cursor.isClosed())
-                cursor.close();
+            if (cursor != null && !cursor.isClosed()) cursor.close();
         }
     }
 
